import argparse
import imgix 

if __name__ == "__main__":
	builder = imgix.UrlBuilder("static.imgix.net", sign_key="sda2345")
	print builder.create_url("/treefrog.jpg?testing/", w=10, h=400, fit="crop")



# -*- coding: utf-8 -*-

import hashlib
import urllib
import urlparse

from constants import *

class UrlHelper(object):

    @classmethod
    def from_url(cls, url):
        pass

    def __init__(self, domain, path, scheme="http",
                 sign_key=None, sign_mode=SIGNATURE_MODE_QUERY, **parameters):
        self._scheme = scheme
        self._host = domain
        self._path = path
        self._sign_key = sign_key
        if sign_mode != SIGNATURE_MODE_QUERY:
            raise Exception("Path signatures are not supported yet.")
        self._sign_mode = sign_mode
        self._parameters = {}
        for key, value in parameters.iteritems():
            self.set_parameter(key, value)

    def set_parameter(self, key, value):
        if not value:
            self.delete_parameter(key)
            return

        self._parameters[key] = value

    def delete_parameter(self, key):
        if key in self._parameters:
            del self._parameters[key]

    def _str_is_ascii(self, s):
        try:
            s.decode('ascii')
            return True
        except:
            return False

    def __str__(self):
        query_pairs = []

        for key in sorted(self._parameters.keys()):
            query_pairs.append((str(key), str(self._parameters[key])))

        path = self._path

        if path.startswith("http"):
            path = urllib.quote(self._path, safe="")

        if not path.startswith("/"):
            path = "/" + path  # Fix web proxy style URLs

        if not self._str_is_ascii(path):
            path = urllib.quote(self._path)

        query = urllib.urlencode(query_pairs)
        if self._sign_key:
            delim = "" if query == "" else "?"
            signing_value = self._sign_key + path + delim + query
            signature = hashlib.md5(signing_value).hexdigest()

            if query:
                query += "&s=" + signature
            else:
                query = "s=" + signature

        return urlparse.urlunparse([
            self._scheme,
            self._host,
            path,
            "",
            query,
            "",
        ])



# -*- coding: utf-8 -*-

import zlib

from constants import *
from urlhelper import UrlHelper

class UrlBuilder(object):

    def __init__(self, domains, use_https=False, sign_key=None,
                 sign_mode=SIGNATURE_MODE_QUERY,
                 shard_strategy=SHARD_STRATEGY_CRC):
        if not isinstance(domains, list):
            domains = [domains]
        self._domains = domains
        self._sign_key = sign_key
        self._sign_mode = sign_mode
        self._use_https = use_https
        self._shard_strategy = shard_strategy
        self._shard_next_index = 0

    def create_url(self, path, **parameters):
        if self._shard_strategy == SHARD_STRATEGY_CRC:
            crc = zlib.crc32(path) & 0xffffffff
            index = crc % len(self._domains)  # Deterministically choose domain
            domain = self._domains[index]

        elif self._shard_strategy == SHARD_STRATEGY_CYCLE:
            domain = self._domains[self._shard_next_index]
            self._shard_next_index = (
                self._shard_next_index + 1) % len(self._domains)

        else:
            domain = self._domains[0]

        scheme = "https" if self._use_https else "http"
        url_obj = UrlHelper(domain, path, scheme,
                            sign_key=self._sign_key, sign_mode=self._sign_mode,
                            **parameters)
        return str(url_obj)


import os
import sys
try:
	from setuptools import setup
except:
	from distutils.core import setup
from distutils.command.build_py import build_py

path, script = os.path.split(sys.argv[0])
os.chdir(os.path.abspath(path))

VERSION="0.0.3"

install_requires = []

setup(name='imgix',
	cmdclass={'build_py': build_py},
	version=VERSION,
	description='Python client library for imgix.',
	author='imgix',
	author_email='support@imgix.com',
	url='https://github.com/imgix/imgix-python',
	packages=['imgix'],
	install_requires=install_requires
)



# -*- coding: utf-8 -*-

from constants import *
from urlbuilder import UrlBuilder

__all__ = [
    'UrlBuilder',
    'SHARD_STRATEGY_CRC',
    'SHARD_STRATEGY_CYCLE',
    'SIGNATURE_MODE_QUERY',
    'SIGNATURE_MODE_PATH',
]